@@ -4,6 +4,11 @@ import pareto as pt
 
 
 def MO_calculate(soln):
+	"""
+	Calculates objective vector [overtime, idletime, waiting time]
+	:param soln: (ndarray) a solution
+	:return: (ndarray) objective vector
+	"""
 	over_time_score = 0
 	idle_time_score = 0
 	waiting_time_score = 0
@@ -42,38 +47,14 @@ def MO_calculate(soln):
 	waiting_time_score = sum(res_w)
 	c = np.array(([over_time_score, idle_time_score, waiting_time_score]))
 	return c
-	#return np.ma.log(c).filled(0)
-
-def MO_calculate_diff(soln, curr_score, swap):
-
-	alpha = 2.0  # multiplier for actual surgeries
-	beta = 1.0  # multiplier for predicted surgeries
-
-	score_vec1 = []
-	score_vec2 = []
-	swap1name = swap[0][0]
-	swap1day = swap[0][1]
-	swap1OT = swap[0][2]
-	swap1start = swap[0][3]
-	swap1end = swap[0][4]
-	swap2name = swap[1][0]
-	swap2day = swap[1][1]
-	swap2OT = swap[1][2]
-	swap2start = swap[1][3]
-	swap2end = swap[1][4]
-	# calculate scores for first slot
-	overtime1 = soln[swap1day][swap1OT][swap1start]
-	#idletime1 =
-	if int(str(swap1name)[:2]) == 11:
-		waitingtime1 = swap1day * alpha
-	elif int(str(swap1name)[:2]) == 12:
-		waitingtime1 = swap1day * beta
-	#else:
-		print("Warning: not 11 nor 12")
-	# calculate scores for secon slot
 
 
 def calc_crowding_distance(F):
+	"""
+	Calculate crowding distance of each solution
+	:param F: (list) scores of all solutions
+	:return: (list) crowding distance of each solution
+	"""
 	infinity = 1e+14
 
 	n_points = F.shape[0]
@@ -122,25 +103,19 @@ def calc_crowding_distance(F):
 	return crowding
 
 
-def calculate_delta_S(curr, neighbor, T): # scalarizing function
-	lambda_o = 1
-	lambda_i = 1
-	lambda_w = 1  # can be adjusted to favour which objective more, might need to adjust because the scales are different
-	lambda_ = [lambda_o, lambda_i, lambda_w]
-	diff_vector = MO_calculate(neighbor) - MO_calculate(curr)
-	pi = np.where(diff_vector <= 0, 1, np.exp(-diff_vector/T)) # Ulungu's paper
-	v = np.power(pi, lambda_)
-	return np.prod(v)
-
-
 def calculate_delta_S2(curr, perturb, T, lambdas_, pareto_scores): # scalarizing function
+	"""
+	Scalarizing function for UMOSA
+	:param curr: (ndarray) current solution
+	:param perturb: (ndarray) the neighbouring solution
+	:param T: (float) current temperature
+	:param lambdas_: (list) weight vectors
+	:param pareto_scores: (list) of scores of solutions on the current pareto front
+	:return: (float) probability of acceptance
+	"""
 	pareto_scores = np.array(pareto_scores)
 	pareto_scores = np.delete(pareto_scores, -1, axis=1)
 	max_overtime, max_idletime, max_waittime = pareto_scores.max(axis = 0)
-	# min_overtime, min_idletime, min_waittime = pareto_scores.min(axis=0)
-	# range_over = max_overtime - min_overtime
-	# range_idle = max_idletime - min_idletime
-	# range_wait = max_waittime - min_waittime
 	range_arr = np.array([max_overtime, max_idletime, max_waittime])
 	lambdas_ = np.divide(lambdas_,range_arr)
 	lambdas_ = lambdas_ / np.sum(lambdas_)
